@@ -26,9 +26,18 @@ FAILEDOPERATION_ACTIONUNREACHABLE = 'FailedOperation.ActionUnreachable'
 # 广播任务正在执行。
 FAILEDOPERATION_BROADCASTTASKISRUNNING = 'FailedOperation.BroadcastTaskIsRunning'
 
+# 云存 AI 套餐生效时长不能超过当前云存套餐生效时长
+FAILEDOPERATION_CLOUDSTORAGEAIPACKAGEEXPIRETIMEEXCEEDED = 'FailedOperation.CloudStorageAIPackageExpireTimeExceeded'
+
 # 产品未开通视频AI分析服务
 FAILEDOPERATION_CLOUDSTORAGEAISERVICENOTENABLED = 'FailedOperation.CloudStorageAIServiceNotEnabled'
 
+# 云存 AI 分析任务已存在，不支持重复创建
+FAILEDOPERATION_CLOUDSTORAGEAISERVICETASKALREADYEXISTS = 'FailedOperation.CloudStorageAIServiceTaskAlreadyExists'
+
+# 需先开通云存套餐
+FAILEDOPERATION_CLOUDSTORAGEPACKAGEREQUIRED = 'FailedOperation.CloudStoragePackageRequired'
+
 # 设备已经被禁用。
 FAILEDOPERATION_DEVICEALREADYDISABLED = 'FailedOperation.DeviceAlreadyDisabled'
 
@@ -47,12 +56,18 @@ FAILEDOPERATION_DEVICEOFFLINE = 'FailedOperation.DeviceOffline'
 # 存在其他升级任务。
 FAILEDOPERATION_OTHERUPDATETASKEXIST = 'FailedOperation.OtherUpdateTaskExist'
 
+# 产品未开通 IoT Video 服务
+FAILEDOPERATION_PRODUCTIOTVIDEOSERVICENOTENABLED = 'FailedOperation.ProductIotVideoServiceNotEnabled'
+
 # 产品尚未发布。
 FAILEDOPERATION_PRODUCTNOTRELEASED = 'FailedOperation.ProductNotReleased'
 
 # RRPC接口未收到设备端响应。
 FAILEDOPERATION_RRPCTIMEOUT = 'FailedOperation.RRPCTimeout'
 
+# 请求TRTC失败
+FAILEDOPERATION_REQUESTTRTCFAIL = 'FailedOperation.RequestTRTCFail'
+
 # 转发已经停止。
 FAILEDOPERATION_RULEALREADYDISABLED = 'FailedOperation.RuleAlreadyDisabled'
 
@@ -101,6 +116,12 @@ INVALIDPARAMETER_FIRMWAREALREADYEXIST = 'InvalidParameter.FirmwareAlreadyExist'
 # 产品不是网关类型，无法绑定子产品。
 INVALIDPARAMETER_PRODUCTISNOTGATEWAY = 'InvalidParameter.ProductIsNotGateway'
 
+# RoomId已存在
+INVALIDPARAMETER_ROOMIDEXIST = 'InvalidParameter.RoomIdExist'
+
+# UserId数量超出限制
+INVALIDPARAMETER_USERIDOVERLIMIT = 'InvalidParameter.UserIdOverLimit'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -128,6 +149,9 @@ INVALIDPARAMETERVALUE_APPNOTEXISTS = 'InvalidParameterValue.AppNotExists'
 # 检查第三方URL超时或失败。
 INVALIDPARAMETERVALUE_CHECKFORWARDURLFAIL = 'InvalidParameterValue.CheckForwardURLFail'
 
+# 指定的云存 AI 套餐不存在
+INVALIDPARAMETERVALUE_CLOUDSTORAGEAIPACKAGEIDNOTEXIST = 'InvalidParameterValue.CloudStorageAIPackageIdNotExist'
+
 # 创建的设备名已存在。
 INVALIDPARAMETERVALUE_DEVICEALREADYEXIST = 'InvalidParameterValue.DeviceAlreadyExist'
 
@@ -233,6 +257,9 @@ INVALIDPARAMETERVALUE_MSGTITLEINVALID = 'InvalidParameterValue.MsgTitleInvalid'
 # 消息类型非法。
 INVALIDPARAMETERVALUE_MSGTYPEINVALID = 'InvalidParameterValue.MsgTypeInvalid'
 
+# 无权限。
+INVALIDPARAMETERVALUE_NOPERMISSION = 'InvalidParameterValue.NoPermission'
+
 # 操作不支持。
 INVALIDPARAMETERVALUE_OPERATIONDENIED = 'InvalidParameterValue.OperationDenied'
 
@@ -332,6 +359,9 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 已有量产进行，请等待量产完成。
 RESOURCEINSUFFICIENT_BATCHPRODUCTIONISRUNNING = 'ResourceInsufficient.BatchProductionIsRunning'
 
+# 云存 AI 分析任务创建额度不足
+RESOURCEINSUFFICIENT_CLOUDSTORAGEAISERVICETASKQUOTAINSUFFICIENT = 'ResourceInsufficient.CloudStorageAIServiceTaskQuotaInsufficient'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
@@ -341,6 +371,12 @@ RESOURCENOTFOUND_BATCHPRODUCTIONNOTEXIST = 'ResourceNotFound.BatchProductionNotE
 # 上传URL无法获取。
 RESOURCENOTFOUND_CANNOTGETFROMURL = 'ResourceNotFound.CannotGetFromUrl'
 
+# 云存AI分析任务不存在
+RESOURCENOTFOUND_CLOUDSTORAGEAISERVICETASK = 'ResourceNotFound.CloudStorageAIServiceTask'
+
+# 云存AI分析任务输出文件不存在
+RESOURCENOTFOUND_CLOUDSTORAGEAISERVICETASKFILE = 'ResourceNotFound.CloudStorageAIServiceTaskFile'
+
 # 存在重复设备。
 RESOURCENOTFOUND_DEVICEDUPKEYEXIST = 'ResourceNotFound.DeviceDupKeyExist'
 
@@ -446,6 +482,9 @@ UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOINSTANCE = 'UnauthorizedOperation.NoPe
 # 产品ACL错误。
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOPRODUCT = 'UnauthorizedOperation.NoPermissionToStudioProduct'
 
+# 无权操作该房间
+UNAUTHORIZEDOPERATION_NOPERMISSIONTOTRTCROOM = 'UnauthorizedOperation.NoPermissionToTRTCRoom'
+
 # 您的帐号未实名认证，请登录腾讯云进行实名认证
 UNAUTHORIZEDOPERATION_NOVERIFIED = 'UnauthorizedOperation.NoVerified'
 
@@ -470,6 +509,12 @@ UNSUPPORTEDOPERATION_BINDSEXISTUNDERFENCE = 'UnsupportedOperation.BindsExistUnde
 # 存在重复的绑定关系。
 UNSUPPORTEDOPERATION_CANNOTREBINDFAMILY = 'UnsupportedOperation.CannotReBindFamily'
 
+# 云存套餐与云存 AI 套餐时长不匹配
+UNSUPPORTEDOPERATION_CLOUDSTORAGEPACKAGETIMEMISMATCH = 'UnsupportedOperation.CloudStoragePackageTimeMismatch'
+
+# 云存套餐与云存 AI 套餐类型不匹配
+UNSUPPORTEDOPERATION_CLOUDSTORAGEPACKAGETYPEMISMATCH = 'UnsupportedOperation.CloudStoragePackageTypeMismatch'
+
 # 创建的设备已经存在。
 UNSUPPORTEDOPERATION_DEVICEDUPKEYEXIST = 'UnsupportedOperation.DeviceDupKeyExist'
 
@@ -542,6 +587,9 @@ UNSUPPORTEDOPERATION_STAFFPOOLDUPNAMEEXIST = 'UnsupportedOperation.StaffPoolDupN
 # LoRa频点还被节点或网关使用。
 UNSUPPORTEDOPERATION_STUDIOLORAFREQINUSED = 'UnsupportedOperation.StudioLoRaFreqInUsed'
 
+# TRTC增值服务未开通
+UNSUPPORTEDOPERATION_TRTCSERVICENOTOPEN = 'UnsupportedOperation.TRTCServiceNotOpen'
+
 # 账户有未支付订单。
 UNSUPPORTEDOPERATION_UNPAIDORDER = 'UnsupportedOperation.UnpaidOrder'
 
